﻿using Modèle;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Persistance
{
    /// <summary>
    /// Classe IPersistanceManager décrivant le comportement des différentes instances de persistance
    /// </summary>
    public interface IPersistanceManager
    { 
        /// <summary>
        /// Chargement des requins
        /// </summary>
        /// <returns>List de Requin : une pour les requins de l'application, une pour les requins ajoutés par les utilisateurs, et une pour les requins édités par les utilisateurs</returns>
        (List<Requin> reqs, List<Requin> reqsAdd, List<Requin> reqsEdit) LoadRequins();
        /// <summary>
        /// Sauvegarde des requins
        /// </summary>
        /// <param name="reqs"></param>
        /// <param name="reqsAdd"></param>
        /// <param name="reqsEdit"></param>
        void SaveRequins(List<Requin> reqs, List<Requin> reqsAdd, List<Requin> reqsEdit);
        /// <summary>
        /// Chargement des utilisateurs
        /// </summary>
        /// <returns>List d'Utilisateur et d'Expert</returns>
        (List<Utilisateur> users, List<Expert> experts) LoadUsers();
        /// <summary>
        /// Sauvegarde des utilisateurs
        /// </summary>
        /// <param name="users"></param>
        /// <param name="experts"></param>
        void SaveUsers(List<Utilisateur> users, List<Expert> experts);
        /// <summary>
        /// Chargement des fun facts
        /// </summary>
        /// <returns>List de String les fun facts</returns>
        List<String> LoadFunFacts();
        /// <summary>
        /// Sauvegarde des fun facts
        /// </summary>
        /// <param name="funFacts"></param>
        void SaveFunFacts(List<String> funFacts);

    }
}