﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Threading.Tasks;
using System.Windows;
using Business;
using Persistance;

namespace WpfApp1
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        /// <summary>
        /// L'IPersistanceManager qui fait référence à notre DataContract
        /// </summary>
        public static IPersistanceManager strat { get; private set; }
            = new DataContractPersistance();
        /// <summary>
        /// L'IPersistanceManager qui fait référence à notre stub
        /// </summary>
        public static IPersistanceManager stubtruc { get; private set; }
            = new StubLib.Stub();
        /// <summary>
        /// Le Manager des requins qui contiendra toutes les listes
        /// </summary>
        public Manager LeManager { get; private set; } = new Manager(strat);
        /// <summary>
        /// Le Manager des utilisateurs qui contiendra toutes les listes
        /// </summary>
        public ManagerUsers LeManagerUsers { get; private set; } = new ManagerUsers(strat);

        /// <summary>
        /// Charge les données des fichiers de persistance dans l'application
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Application_Activated(object sender, EventArgs e)
        {
            LeManager.LoadRequins();
            LeManagerUsers.LoadUsers();
            LeManager.LoadFunFacts();       
        }

        /// <summary>
        /// Sauvegarde les données de l'application dans les fichiers de persistance
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Application_Deactivated(object sender, EventArgs e)
        {
            LeManager.SaveRequins();
            LeManagerUsers.SaveUsers();
            LeManager.SaveFunFacts();
        }
    }
}
